@@ -51,6 +51,9 @@ path:
 prometheus:
   indices: false
 
+# increase the max header size above 8kb default
+http.max_header_size: 128kb
+
 opendistro_security:
   authcz.admin_dn:
   - CN=system.admin,OU=OpenShift,O=Logging
